##################################################################
#   5724-E34
#   (c) Copyright IBM Corporation 2008, 2009.
#   All rights reserved.
#
#   The source code for this program is not published or otherwise
#   divested of its trade secrets, irrespective of what has been
#   deposited with the U.S. Copyright Office.
##################################################################
#  File: GOSALES_RUN_SCRIPTS.sh
#
#  Description:
#     This script must be started from the setupGSDB.sh
#     script.
#     This file performs one or more of the following functions :
#       - ATTACH to the NODENAME
#       - Creates the database, bufferpool and tablespaces
#       - Connects to the database
#       - Executes the SQL scripts that were generated in the
#         RUN_GOSALES_IMPORT.bat file to create the tables, indexes,
#         foreign keys, views, privileges and stored procedures that
#         make up the GOSALES database
#
##################################################################

terminateRunScripts()
{
   db2 connect reset > /dev/null  2>&1
   db2 terminate  > /dev/null  2>&1
}

CreateTableError( )
{
   echo Error creating tables for schema $1
   echo Error creating tables for schema $1 >> "${GOSALES_LOG_DIR}$1_TABLES.LOG"
   terminateRunScripts
}

VerifyTableRowCounts( )
{
   echo Verifying row counts
   if [ -e GOSALES_VERIFY.SQL ] ; then
      db2 -td@ -f GOSALES_VERIFY.SQL > "${GOSALES_LOG_DIR}GOSALES_VERIFY.LOG"

      db2 call ${GOSALES_SCHEMA}.VERIFY_DATA\(?\) > "${GOSALES_LOG_DIR}GOSALES_VERIFY_DATA.LOG"

      GOSALES_OUTPUT=`cat "${GOSALES_LOG_DIR}GOSALES_VERIFY_DATA.LOG"`

      case ${GOSALES_OUTPUT} in
         *successful*)
            echo "Table row count validation successful."
            ;;
         *)
            echo "Table row count validation failed."
            echo "Table row count validation failed." >> "${GOSALES_ERROR_LOG}"
            ;;
      esac
   fi
}

#########################################################################
# Verify the script was called correctly
#########################################################################

if [ "${GOSALES_START}" != "1" ] ; then
   echo This script must be called from setupGSDB.sh - Quitting
   exit -1
fi

##################################################################
# Create the database
# - needs to attach
##################################################################
echo "Starting GOSALES_RUN_SCRIPTS"

db2 connect reset > /dev/null  2>&1

if [ "${GOSALES_CREATEDB}" == "Y" -a "${GOSALES_ONLY_VERIFY}" == "N" ] ; then
   # Attach if the NODE is provided

   if [ "${GOSALES_NODENAME}" != "" ] ; then
      if [ "${GOSALES_ADMIN_USERNAME}" == "" ] ; then
         # Attempt to attach without a userid
         db2 attach to ${GOSALES_NODENAME}
      else
         if [ "${GOSALES_ADMIN_PASSWORD}" != "" ] ; then
            db2 attach to ${GOSALES_NODENAME} user ${GOSALES_ADMIN_USERNAME} using ${GOSALES_ADMIN_PASSWORD}
         else
            # Prompt the admin user for the password
            db2 attach to ${GOSALES_NODENAME} user ${GOSALES_ADMIN_USERNAME}
         fi
      fi

      # If an error occured while attaching to the node, then report the
      # error and exit.
      if [ $? -ne 0 ] ; then
         echo Attach to node ${GOSALES_NODENAME} failed.
         echo Attach to node ${GOSALES_NODENAME} failed. >> "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"
         return -1;
      else
         echo Attach to node ${GOSALES_NODENAME} was successful. >> "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"
      fi
   fi


   echo Creating database
   ##################################################################
   # Drop the existing database in the shell since we dont worry
   # about the error of the result
   ##################################################################
   db2 drop database ${GOSALES_INST} >> "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"

   ##################################################################
   # Run the script to create the database
   ##################################################################
   db2 -td@ -f GOSALES_CREATE_DB.SQL >> "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"

   if [ $? != 0 ] ; then
      echo Error creating the database ${GOSALES_INST}.
      cat < "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"
      terminateRunScripts;
      return -1;
   fi

   # Grant DBADM access to the
   #
   # db2 connect to $GOSALES_INST
   #
   if [ "${GOSALES_ADMIN_USERNAME}" != "" ]; then
        db2 connect to $GOSALES_INST >> "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"
        db2 grant DBADM on database to USER ${GOSALES_ADMIN_USERNAME} >> "${GOSALES_LOG_DIR}GOSALES_CREATE_DB.LOG"
        if [ $? != 0 ] ; then echo Error granting DBADM permission to ${GOSALES_ADMIN_USERNAME}; fi;
   fi
fi

##################################################################
# Connect to the database
##################################################################

db2 connect reset > /dev/null  2>&1

echo Connecting to ${GOSALES_INST}

if [ "${GOSALES_ADMIN_USERNAME}" == "" ] ; then
   # Attempt to connect without a userid
   db2 connect to ${GOSALES_INST}
else
   if [ "${GOSALES_ADMIN_PASSWORD}" != "" ] ; then
      db2 connect to ${GOSALES_INST} user {GOSALES_ADMIN_USERNAME} using ${GOSALES_ADMIN_PASSWORD}
   else
      # Prompt the admin user for the password
      db2 connect to ${GOSALES_INST} user ${GOSALES_ADMIN_USERNAME}
   fi
fi


if [ $? != 0 ] ; then
   echo Error connecting to the database ${GOSALES_INST}.
   terminateRunScripts;
   return -1;
fi

if [ ${GOSALES_ONLY_VERIFY} == "Y" ] ; then
   VerifyTableRowCounts
   return 0;
fi


##################################################################
# Create the bufferpool and tablespace if required
##################################################################

if [ "${GOSALES_CREATE_BP_AND_TS}" == "Y" ] ; then
   echo Creating bufferpool and tablespace.
   db2 -td@ -f GOSALES_CREATE_TS.SQL > "${GOSALES_LOG_DIR}GOSALES_CREATE_TS.LOG"

   if [ $? != 0 ] ; then
      echo Error creating bufferpool or tablespace.
      cat < "${GOSALES_LOG_DIR}GOSALES_CREATE_TS.LOG"
      terminateRunScripts;
      return -1;
   fi
fi


##################################################################
# Drop the existing tables, views and stored procedures
# Ignore any errors
##################################################################
if [ "${GOSALES_CLEAN}" == "Y" ] ; then
   echo Dropping existing database objects
   db2 -td@ -vf GOSALES_DROP.SQL > "${GOSALES_LOG_DIR}GOSALES_DROP.LOG"
   db2 -td@ -vf WAREHOUSE_TUTORIAL_CLEANUP.SQL >> "${GOSALES_LOG_DIR}GOSALES_DROP.LOG"
fi


##################################################################
# Create the tables
##################################################################
echo Creating tables.

if [ -e GOSALES_TABLES.SQL ] ; then
   db2 -td@ -f GOSALES_TABLES.SQL > "${GOSALES_LOG_DIR}GOSALES_TABLES.LOG"
   if [ $? != 0 ] ; then CreateTableError GOSALES; return -1; fi;
fi

if [ -e GOSALESHR_TABLES.SQL ] ; then
   db2 -td@ -f GOSALESHR_TABLES.SQL > "${GOSALES_LOG_DIR}GOSALESHR_TABLES.LOG"
   if [ $? != 0 ] ; then CreateTableError GOSALESHR; return -1; fi;
fi

if [ -e GOSALESMR_TABLES.SQL ] ; then
   db2 -td@ -f GOSALESMR_TABLES.SQL > "${GOSALES_LOG_DIR}GOSALESMR_TABLES.LOG"
   if [ $? != 0 ] ; then CreateTableError GOSALESMR; return -1; fi;
fi

if [ -e GOSALESRT_TABLES.SQL ] ; then
   db2 -td@ -f GOSALESRT_TABLES.SQL > "${GOSALES_LOG_DIR}GOSALESRT_TABLES.LOG"
   if [ $? != 0 ] ; then CreateTableError GOSALESRT; return -1; fi;
fi

if [ -e GOSALESCT_TABLES.SQL ] ; then
   db2 -td@ -f GOSALESCT_TABLES.SQL > "${GOSALES_LOG_DIR}GOSALESCT_TABLES.LOG"
   if [ $? != 0 ] ; then CreateTableError GOSALESCT; return -1; fi;
fi

if [ -e GOSALESDW_TABLES.SQL ] ; then
   db2 -td@ -f GOSALESDW_TABLES.SQL > "${GOSALES_LOG_DIR}GOSALESDW_TABLES.LOG"
   if [ $? != 0 ] ; then CreateTableError GOSALESDW; return -1; fi;
fi

displayTime=`date`
echo
echo Load started at ${displayTime} >> "${GOSALES_LOG_DIR}GOSALES_LOAD.LOG"
echo Loading data.
##################################################################
# Load the data
##################################################################
db2 -td@ -f GOSALES_LOAD.SQL > "${GOSALES_LOG_DIR}GOSALES_LOAD.LOG"
if [ $? != 0 ] ; then
   cat < "${GOSALES_LOG_DIR}GOSALES_LOAD.LOG"
   displayTime=`date`
   echo Error loading data
   echo Load ended at ${displayTime} >> "${GOSALES_LOG_DIR}GOSALES_LOAD.LOG"
   terminateRunScripts;
   return -1;
fi

displayTime=`date`
echo Load ended at ${displayTime} >> "${GOSALES_LOG_DIR}GOSALES_LOAD.LOG"

##################################################################
# Create
# primary keys
##################################################################
echo Creating Primary Keys.
if [ -e GOSALES_PK.SQL ] ; then
   db2 -td@ -f GOSALES_PK.SQL > "${GOSALES_LOG_DIR}GOSALES_PK.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES PRIMARY KEYS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_PK.SQL ] ; then
   db2 -td@ -f GOSALESHR_PK.SQL > "${GOSALES_LOG_DIR}GOSALESHR_PK.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESHR PRIMARY KEYS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_PK.SQL ] ; then
   db2 -td@ -f GOSALESMR_PK.SQL > "${GOSALES_LOG_DIR}GOSALESMR_PK.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESMR PRIMARY KEYS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_PK.SQL ] ; then
   db2 -td@ -f GOSALESRT_PK.SQL > "${GOSALES_LOG_DIR}GOSALESRT_PK.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESRT PRIMARY KEYS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_PK.SQL ] ; then
   db2 -td@ -f GOSALESCT_PK.SQL > "${GOSALES_LOG_DIR}GOSALESCT_PK.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESCT PRIMARY KEYS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_PK.SQL ] ; then
   db2 -td@ -f GOSALESDW_PK.SQL > "${GOSALES_LOG_DIR}GOSALESDW_PK.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESDW PRIMARY KEYS" >> "${GOSALES_ERROR_LOG}"; fi;
fi

##################################################################
# Create indexes
##################################################################
echo Creating indexes.
if [ -e GOSALES_INDEXES.SQL ] ; then
   db2 -td@ -f GOSALES_INDEXES.SQL > "${GOSALES_LOG_DIR}GOSALES_INDEXES.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES INDEXES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_INDEXES.SQL ] ; then
   db2 -td@ -f GOSALESHR_INDEXES.SQL > "${GOSALES_LOG_DIR}GOSALESHR_INDEXES.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESHR INDEXES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_INDEXES.SQL ] ; then
   db2 -td@ -f GOSALESMR_INDEXES.SQL > "${GOSALES_LOG_DIR}GOSALESMR_INDEXES.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESMR INDEXES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_INDEXES.SQL ] ; then
   db2 -td@ -f GOSALESRT_INDEXES.SQL > "${GOSALES_LOG_DIR}GOSALESRT_INDEXES.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESRT INDEXES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_INDEXES.SQL ] ; then
   db2 -td@ -f GOSALESCT_INDEXES.SQL > "${GOSALES_LOG_DIR}GOSALESCT_INDEXES.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESCT INDEXES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_INDEXES.SQL ] ; then
   db2 -td@ -f GOSALESDW_INDEXES.SQL > "${GOSALES_LOG_DIR}GOSALESDW_INDEXES.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESDW INDEXES" >> "${GOSALES_ERROR_LOG}"; fi;
fi

##################################################################
# Create constraints
##################################################################
echo Creating constraints.
if [ -e GOSALES_CONSTRAINTS.SQL ] ; then
   db2 -td@ -f GOSALES_CONSTRAINTS.SQL > "${GOSALES_LOG_DIR}GOSALES_CONSTRAINTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES CONSTRAINTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_CONSTRAINTS.SQL ] ;
   then db2 -td@ -f GOSALESHR_CONSTRAINTS.SQL > "${GOSALES_LOG_DIR}GOSALESHR_CONSTRAINTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESHR CONSTRAINTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_CONSTRAINTS.SQL ] ; then
   db2 -td@ -f GOSALESMR_CONSTRAINTS.SQL > "${GOSALES_LOG_DIR}GOSALESMR_CONSTRAINTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESMR CONSTRAINTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_CONSTRAINTS.SQL ] ; then
   db2 -td@ -f GOSALESRT_CONSTRAINTS.SQL > "${GOSALES_LOG_DIR}GOSALESRT_CONSTRAINTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESRT CONSTRAINTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_CONSTRAINTS.SQL ] ; then
   db2 -td@ -f GOSALESCT_CONSTRAINTS.SQL > "${GOSALES_LOG_DIR}GOSALESCT_CONSTRAINTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESCT CONSTRAINTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_CONSTRAINTS.SQL ] ; then
   db2 -td@ -f GOSALESDW_CONSTRAINTS.SQL > "${GOSALES_LOG_DIR}GOSALESDW_CONSTRAINTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESDW CONSTRAINTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi

##################################################################
# Create stored procedures
##################################################################
echo Creating stored procedures
if [ -e GOSALES_SP.SQL ] ; then
   db2 -td@ -f GOSALES_SP.SQL > "${GOSALES_LOG_DIR}GOSALES_SP.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES STORED PROCEDURES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_SP.SQL ] ; then
   db2 -td@ -f GOSALESHR_SP.SQL > "${GOSALES_LOG_DIR}GOSALESHR_SP.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESHR STORED PROCEDURES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_SP.SQL ] ; then
   db2 -td@ -f GOSALESMR_SP.SQL > "${GOSALES_LOG_DIR}GOSALESMR_SP.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESMR STORED PROCEDURES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_SP.SQL ] ; then
   db2 -td@ -f GOSALESRT_SP.SQL > "${GOSALES_LOG_DIR}GOSALESRT_SP.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESRT STORED PROCEDURES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_SP.SQL ] ; then
   db2 -td@ -f GOSALESCT_SP.SQL > "${GOSALES_LOG_DIR}GOSALESCT_SP.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESCT STORED PROCEDURES" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_SP.SQL ] ; then
   db2 -td@ -f GOSALESDW_SP.SQL > "${GOSALES_LOG_DIR}GOSALESDW_SP.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESDW STORED PROCEDURES" >> "${GOSALES_ERROR_LOG}"; fi;
fi

##################################################################
# Create views
##################################################################
echo Creating views
if [ -e GOSALES_VIEWS.SQL ] ; then
   db2 -td@ -f GOSALES_VIEWS.SQL > "${GOSALES_LOG_DIR}GOSALES_VIEWS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES VIEWS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_VIEWS.SQL ] ; then
   db2 -td@ -f GOSALESHR_VIEWS.SQL > "${GOSALES_LOG_DIR}GOSALESHR_VIEWS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESHR VIEWS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_VIEWS.SQL ] ; then
   db2 -td@ -f GOSALESMR_VIEWS.SQL > "${GOSALES_LOG_DIR}GOSALESMR_VIEWS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESMR VIEWS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_VIEWS.SQL ] ; then
   db2 -td@ -f GOSALESRT_VIEWS.SQL > "${GOSALES_LOG_DIR}GOSALESRT_VIEWS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESRT VIEWS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_VIEWS.SQL ] ; then
   db2 -td@ -f GOSALESCT_VIEWS.SQL > "${GOSALES_LOG_DIR}GOSALESCT_VIEWS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESCT VIEWS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_VIEWS.SQL ] ; then
   db2 -td@ -f GOSALESDW_VIEWS.SQL > "${GOSALES_LOG_DIR}GOSALESDW_VIEWS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESDW VIEWS" >> "${GOSALES_ERROR_LOG}"; fi;
fi



##################################################################
# Create grants
##################################################################
echo Granting Permissions.
if [ -e GOSALES_GRANTS.SQL ] ; then
   db2 -td@ -f GOSALES_GRANTS.SQL > "${GOSALES_LOG_DIR}GOSALES_GRANTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES GRANTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_GRANTS.SQL ] ; then
   db2 -td@ -f GOSALESHR_GRANTS.SQL > "${GOSALES_LOG_DIR}GOSALESHR_GRANTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESHR GRANTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_GRANTS.SQL ] ; then
   db2 -td@ -f GOSALESMR_GRANTS.SQL > "${GOSALES_LOG_DIR}GOSALESMR_GRANTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESMR GRANTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_GRANTS.SQL ] ; then
   db2 -td@ -f GOSALESRT_GRANTS.SQL > "${GOSALES_LOG_DIR}GOSALESRT_GRANTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESRT GRANTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_GRANTS.SQL ] ; then
   db2 -td@ -f GOSALESCT_GRANTS.SQL > "${GOSALES_LOG_DIR}GOSALESCT_GRANTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESCT GRANTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_GRANTS.SQL ] ; then
   db2 -td@ -f GOSALESDW_GRANTS.SQL > "${GOSALES_LOG_DIR}GOSALESDW_GRANTS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALESDW GRANTS" >> "${GOSALES_ERROR_LOG}"; fi;
fi


##################################################################
# Update statistics
##################################################################
echo Updating statistics
if [ -e GOSALES_RUNSTATS.SQL ] ; then
   db2 -td@ -f GOSALES_RUNSTATS.SQL > "${GOSALES_LOG_DIR}GOSALES_RUNSTATS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES RUNSTATS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESHR_RUNSTATS.SQL ] ; then
   db2 -td@ -f GOSALESHR_RUNSTATS.SQL > "${GOSALES_LOG_DIR}GOSALESHR_RUNSTATS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES RUNSTATS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESMR_RUNSTATS.SQL ] ; then
   db2 -td@ -f GOSALESMR_RUNSTATS.SQL > "${GOSALES_LOG_DIR}GOSALESMR_RUNSTATS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES RUNSTATS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESRT_RUNSTATS.SQL ] ; then
   db2 -td@ -f GOSALESRT_RUNSTATS.SQL > "${GOSALES_LOG_DIR}GOSALESRT_RUNSTATS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES RUNSTATS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESCT_RUNSTATS.SQL ] ; then
   db2 -td@ -f GOSALESCT_RUNSTATS.SQL > "${GOSALES_LOG_DIR}GOSALESCT_RUNSTATS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES RUNSTATS" >> "${GOSALES_ERROR_LOG}"; fi;
fi
if [ -e GOSALESDW_RUNSTATS.SQL ] ; then
   db2 -td@ -f GOSALESDW_RUNSTATS.SQL > "${GOSALES_LOG_DIR}GOSALESDW_RUNSTATS.LOG"
   if [ $? != 0 ] ; then echo "Error creating GOSALES RUNSTATS" >> "${GOSALES_ERROR_LOG}"; fi;
fi


VerifyTableRowCounts

##################################################################
# Terminate and cleanup
##################################################################

terminateRunScripts;
return 0;

