@echo OFF
REM *******************************************************************
REM *  5724-E34
REM *  (c) Copyright IBM Corporation 2008, 2009.
REM *  All rights reserved.
REM *
REM *  The source code for this program is not published or otherwise
REM *  divested of its trade secrets, irrespective of what has been
REM *  deposited with the U.S. Copyright Office.
REM *******************************************************************
REM *
REM *  File: RUN_GOSALES_IMPORT.bat
REM *
REM *  Description :
REM *      This file must be started from the START_GOSALES_IMPORT.bat
REM *      script.
REM *
REM *      This file performs on or more of the following functions :
REM *        - loads the default options from GOSALES_CONFIG.bat
REM *        - parse command line arguments if provided
REM *        - validate the user specified options and may prompt the user
REM *          to provide additional information
REM *        - once the configuration environment variables have been set
REM *          and validated, this script generates SQL scripts that
REM *          will be run by the GOSALES_RUN_SCRIPTS.bat file
REM *
REM ************************************************************************

SETLOCAL
REM ************************************************************************
REM * Verify that the script was called correctly
REM ************************************************************************
IF "%GOSALES_START%"=="1" GOTO CONTINUE_RUN
echo This script must be called from "setupGSDB.bat" - Quitting
GOTO :EOF
:CONTINUE_RUN

REM ************************************************************************
REM * Call the file containing the instance, usernames and schema variables
REM ************************************************************************
CALL "%GOSALES_PARENT_DIR%\GOSalesConfig.bat"

REM ************************************************************************
REM * Process the command line arguments
REM ************************************************************************
set GOSALES_PROMPTS=Y
set GOSALES_CREATE_BP_AND_TS=N
SET GOSALES_ONLY_GENERATE_SQL=N
SET GOSALES_CLEAN=Y
SET GOSALES_ONLY_VERIFY=N
echo.

:PROCESS_PARAMETERS

  if "%1" == "" goto DONE_PARAMETERS

  if /i "%1" == "-genSQL" set GOSALES_ONLY_GENERATE_SQL=Y&& goto CONTINUE

  if /i "%1" == "-verify" set GOSALES_ONLY_VERIFY=Y&& goto CONTINUE

  if /i "%1" neq "-createDB" goto CHECK_INST
    set GOSALES_CREATEDB=Y
    set GOSALES_CREATE_BP_AND_TS=Y
    goto CONTINUE

  :CHECK_INST
  if /i "%1" neq "-database" goto CHECK_USERID
    shift
    set GOSALES_INST=%1
    goto CONTINUE

REM  :CHECK_NODE
REM  if /i "%1" neq "-node" goto CHECK_USERID
REM    shift
REM    if /I "%1" neq "" set GOSALES_NODENAME=%1
REM    goto CONTINUE

  :CHECK_USERID

  if /i "%1" neq "-userid" goto CHECK_PASSWORD
    SHIFT
    if /I "%1" neq "" set GOSALES_ADMIN_USERNAME=%1
    goto CONTINUE

  :CHECK_PASSWORD
  if /i "%1" neq "-password" goto CHECK_NOPROMPT
    REM override the command window title if the password is provided
    REM in order to hide the password
    title RUN_GOSALES_IMPORT.bat
    SHIFT
    if /I "%1" neq "" set GOSALES_ADMIN_PASSWORD=%1
    goto CONTINUE

  :CHECK_NOPROMPT
  if /i "%1" neq "-noprompt" goto CONTINUE
    set GOSALES_PROMPTS=N

  :CONTINUE
  REM *******************************************************************
  REM * Check if there are more parameters to process
  REM *******************************************************************
  SHIFT
  if "%1" neq "" goto PROCESS_PARAMETERS

:DONE_PARAMETERS

REM ************************************************************************
REM * Set up directory variables
REM ************************************************************************
set GOSALES_CURRENT_DIR=%CD%
set GOSALES_IMPORT_FILE_DIR=%GOSALES_PARENT_DIR%\..\data\
set GOSALES_LOG_DIR=%GOSALES_PARENT_DIR%\..\logs\
set GOSALES_ERROR_LOG=%GOSALES_LOG_DIR%GOSALES_ERROR_LOG.LOG

mkdir "%GOSALES_LOG_DIR%" >NUL 2>NUL
REM ************************************************************************
REM * If the error log already exists, delete it
REM ************************************************************************
IF EXIST "%GOSALES_ERROR_LOG%"  del "%GOSALES_ERROR_LOG%"

REM ************************************************************************
REM * Determine the database level
REM ************************************************************************

echo.
echo -------------------------------------------------------------------

for /f %%O in ('db2level ^| find /c "v8."') do SET GOSALES_FOUND=%%O

if "%GOSALES_FOUND%" neq "1" goto VERSION_9_SUPPORT
   echo DB2 version 8 detected - using DB2 Version 8 syntax
   SET GOSALES_DB_CREATE_AUTO_STORAGE=
   SET GOSALES_XML_SUPPORT=N
   goto CREATE_DATABASE

:VERSION_9_SUPPORT
   echo DB2 version 9 or later detected - using DB2 Version 9 syntax
   SET GOSALES_DB_CREATE_AUTO_STORAGE=AUTOMATIC STORAGE YES
   SET GOSALES_XML_SUPPORT=Y

:CREATE_DATABASE

echo.

IF /I "%GOSALES_PROMPTS%" == "N" GOTO DONE_CREATE_DATABASE

REM ************************************************************************
REM * Prompt the user to create the database
REM ************************************************************************

echo -------------------------------------------------------------------
echo Please enter the name of the database ( or the alias ) to be used for the
set /P GOSALES_INST=GOSales sample data (default=%GOSALES_INST%) :

set GOSALES_CREATEDB=Y
echo.
echo -------------------------------------------------------------------
echo This script can create the %GOSALES_INST% database.  Creating the database
echo will cause any existing databases with the same name to be dropped.
echo.
set /P GOSALES_CREATEDB=Would you like to create the database %GOSALES_INST% (Y/N) Default=Y :

IF /I "%GOSALES_CREATEDB%" == "N" GOTO DONE_CREATE_DATABASE

REM ******************************************************************
REM * Force creation of the bufferpool and tablespace if we create
REM * the database
REM ******************************************************************

set GOSALES_CREATE_BP_AND_TS=Y

REM IF "%GOSALES_NODENAME%" neq "" GOTO DONE_CREATE_DATABASE
REM Prompt the user for the NODE
REM echo.
REM echo -------------------------------------------------------------------
REM echo Please enter the DB2 NODE name that will contain the database.  If you are
REM echo logged in as a DB2 administrator you do not need to provide a NODE
REM echo name and the local node will be used.
REM echo.
set GOSALES_NODENAME=
REM set /P GOSALES_NODENAME=Enter the NODE name (or leave empty for local node) :

:DONE_CREATE_DATABASE

REM If the -noprompt option was used an the create DB was not set, then
REM default to CREATEDB=N
IF "%GOSALES_CREATEDB%" == "" set GOSALES_CREATEDB=N

REM ************************************************************************
REM * Check if the values are all set
REM ************************************************************************
IF "%GOSALES_INST%"=="" set /P GOSALES_INST=MISSING VALUE: Enter a value for the DB2 database name:
IF "%GOSALES_INST%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALES_GRANTEES%"=="" set /P GOSALES_GRANTEES=MISSING VALUE: Enter the "GRANT TO" option for the GOSALES schema:
IF "%GOSALES_GRANTEES%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALESDW_GRANTEES%"=="" set /P GOSALESDW_GRANTEES=MISSING VALUE: Enter the "GRANT TO" option for the GOSALESDW schema:
IF "%GOSALESDW_GRANTEES%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALES_SCHEMA%"=="" set /P GOSALES_SCHEMA=MISSING VALUE: Enter a name for the GOSALES schema:
IF "%GOSALES_SCHEMA%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALESHR_SCHEMA%"=="" GOTO set /P GOSALESHR_SCHEMA=MISSING VALUE: Enter a name for the GOSALESHR schema:
IF "%GOSALESHR_SCHEMA%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALESMR_SCHEMA%"=="" set /P GOSALESMR_SCHEMA=MISSING VALUE: Enter a name for the GOSALESMR schema:
IF "%GOSALESMR_SCHEMA%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALESRT_SCHEMA%"=="" set /P GOSALESRT_SCHEMA=MISSING VALUE: Enter a name for the GOSALESRT schema:
IF "%GOSALESRT_SCHEMA%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALESCT_SCHEMA%"=="" set /P GOSALESCT_SCHEMA=MISSING VALUE: Enter a name for the GOSALESCT schema:
IF "%GOSALESCT_SCHEMA%"=="" GOTO QUITTING_MISSINGVALUE

IF "%GOSALESDW_SCHEMA%"=="" set /P GOSALESDW_SCHEMA=MISSING VALUE: Enter a name for the GOSALESDW schema:
IF "%GOSALESDW_SCHEMA%"=="" GOTO QUITTING_MISSINGVALUE

REM ************************************************************************
REM * Do not change the order of this list
REM ************************************************************************
set GOSALES_SCHEMA_LIST=%GOSALES_SCHEMA% %GOSALESRT_SCHEMA% %GOSALESMR_SCHEMA% %GOSALESHR_SCHEMA% %GOSALESCT_SCHEMA% %GOSALESDW_SCHEMA%

REM ************************************************************************
REM * Skip the prompts if the user provided the information in START_GOSALES_IMPORT.bat
REM ************************************************************************

IF /I "%GOSALES_PROMPTS%" == "N" goto DISPLAY_SUMMARY

   REM *****************************************************************
   REM * Test for the existence of an existing database.  If a database do not
   REM * exist then we will get a SQL1013 error.  Any other error or
   REM * success indicates the database exists.  We'll count the number
   REM * of occurances of the SQL1013 - 1 indicates an existing DB,
   REM * 2 indicates there is not an existing database
   REM *****************************************************************

   IF /I "%GOSALES_CREATEDB%" == "N" goto DONE_EXISTING_DB_CHECK

      set GOSALES_EXISTDB=0
      for /f %%O in ('db2 connect to %GOSALES_INST% ^| find /c "SQL1013N" ') do SET GOSALES_EXISTDB=%%O
      IF "%GOSALES_EXISTDB%" == "1" goto DONE_EXISTING_DB_CHECK
         echo.
         echo -------------------------------------------------------------------
         echo The database %GOSALES_INST% already exists and will be dropped.
         echo.
         set GOSALES_CREATEDB=Y
         SET /P GOSALES_CREATEDB=Are you sure you want to drop the existing database? (Y/N) Default=Y :

   :DONE_EXISTING_DB_CHECK
   db2 connect reset > NUL

   REM *****************************************************************
   REM * Ask if user wants to create the buffer pool and tablespaces
   REM * Only prompt if we are not already creating the database
   REM *****************************************************************

   set GOSALES_CREATE_BP_AND_TS=Y

   if /I "%GOSALES_CREATEDB%" == "Y" goto PROMPT_ADMIN

     echo.
     echo To import the data the database needs to contain a 16K bufferpool and
     echo tablespace.  Do you want to create the buffer pool and
     set /P GOSALES_CREATE_BP_AND_TS=tablespace now? (Y/N) Default=Y :

     IF /I %GOSALES_CREATE_BP_AND_TS% == "N" goto PROMPT_ADMIN

       IF "%GOSALES_BP%"=="" set /P GOSALES_BP=Enter the name for the new buffer pool:
       IF "%GOSALES_BP%"=="" GOTO QUITTING_MISSINGVALUE
       IF "%GOSALES_TS%"=="" set /P GOSALES_TS=Enter the name for the new tablespace:
       IF "%GOSALES_TS%"=="" GOTO QUITTING_MISSINGVALUE

   :PROMPT_ADMIN
   REM *******************************************
   REM * Prompt for the username to use to run import
   REM *******************************************
   if "%GOSALES_ADMIN_USERNAME%" neq "" goto DISPLAY_SUMMARY
     echo.
     echo -------------------------------------------------------------------
     echo Enter the DB2 administration username for creating the database
     echo and importing the data.  If no value is provided, then the local
     echo user will attempt to connect without a password.
     set /P GOSALES_ADMIN_USERNAME=Please enter the DB2 admin user name :

:DISPLAY_SUMMARY

REM *****************************************************************
REM * Display the summary and get a final confirmation before starting
REM *****************************************************************

if /I "%GOSALES_PROMPTS%"=="N" goto DISPLAY_SUMMARY2
   echo.
   echo -------------------------------------------------------------------
   echo.
   echo Please confirm the following settings :
   echo.
   goto DISPLAY_SUMMARY3

:DISPLAY_SUMMARY2
   echo This is the configuration for the database setup :
   echo.

:DISPLAY_SUMMARY3

echo Database Name                 : %GOSALES_INST%
echo Drop and Recreate database    : %GOSALES_CREATEDB%
if "%GOSALES_NODENAME%" neq "" echo Node Name                     : %GOSALES_NODENAME%
if /I "%GOSALES_CREATE_BP_AND_TS%" == "N" goto DISPLAY_NO_TS
   echo Create a 16k Bufferpool named : %GOSALES_BP%
   echo Create a 16k Tablespace named : %GOSALES_TS%

:DISPLAY_NO_TS
echo GOSALES   Grant users/groups  : %GOSALES_GRANTEES%
echo GOSALESDW Grant users/groups  : %GOSALESDW_GRANTEES%
echo Administration User name      : %GOSALES_ADMIN_USERNAME%
echo.
echo Import the sample data into the following schemas :
echo        %GOSALES_SCHEMA%
echo        %GOSALESHR_SCHEMA%
echo        %GOSALESMR_SCHEMA%
echo        %GOSALESRT_SCHEMA%
echo        %GOSALESCT_SCHEMA%
echo        %GOSALESDW_SCHEMA%

if /I "%GOSALES_PROMPTS%"=="N" goto GENERATE_SQL_FILES

   set GOSALES_USER_RESPONSE=Y
   SET /P GOSALES_USER_RESPONSE=Continue creating the sample data with these settings? (Y/N) Default=Y :
   if /I "%GOSALES_USER_RESPONSE%" neq "Y" goto QUITTING

:GENERATE_SQL_FILES
echo.
echo Please wait ...
echo.

REM ************************************************************************
REM * Create the sql files by running the batch files
REM ************************************************************************

IF /I "%GOSALES_CREATEDB%" == "N" GOTO CREATE_BUFFERPOOL
CALL GOSALES_CREATE_DB.BAT > GOSALES_CREATE_DB.SQL
set GOSALES_CLEAN=N

:CREATE_BUFFERPOOL
IF /I "%GOSALES_CREATE_BP_AND_TS%" == "N" GOTO CREATE_TABLES
CALL GOSALES_CREATE_TS.BAT > GOSALES_CREATE_TS.SQL

:CREATE_TABLES
IF EXIST GOSALES_TABLES.BAT CALL GOSALES_TABLES.BAT > GOSALES_TABLES.SQL
IF EXIST GOSALESHR_TABLES.BAT CALL GOSALESHR_TABLES.BAT > GOSALESHR_TABLES.SQL
IF EXIST GOSALESMR_TABLES.BAT CALL GOSALESMR_TABLES.BAT > GOSALESMR_TABLES.SQL
IF EXIST GOSALESRT_TABLES.BAT CALL GOSALESRT_TABLES.BAT > GOSALESRT_TABLES.SQL
IF EXIST GOSALESCT_TABLES.BAT CALL GOSALESCT_TABLES.BAT > GOSALESCT_TABLES.SQL
IF EXIST GOSALESDW_TABLES.BAT CALL GOSALESDW_TABLES.BAT > GOSALESDW_TABLES.SQL

REM LOAD THE TABLES
CALL GOSALES_LOAD.BAT > GOSALES_LOAD.SQL

REM GRANTS
IF EXIST GOSALES_GRANTS.BAT CALL GOSALES_GRANTS.BAT > GOSALES_GRANTS.SQL
IF EXIST GOSALESHR_GRANTS.BAT CALL GOSALESHR_GRANTS.BAT > GOSALESHR_GRANTS.SQL
IF EXIST GOSALESMR_GRANTS.BAT CALL GOSALESMR_GRANTS.BAT > GOSALESMR_GRANTS.SQL
IF EXIST GOSALESRT_GRANTS.BAT CALL GOSALESRT_GRANTS.BAT > GOSALESRT_GRANTS.SQL
IF EXIST GOSALESCT_GRANTS.BAT CALL GOSALESCT_GRANTS.BAT > GOSALESCT_GRANTS.SQL
IF EXIST GOSALESDW_GRANTS.BAT CALL GOSALESDW_GRANTS.BAT > GOSALESDW_GRANTS.SQL

:CREATE_PK
IF EXIST GOSALES_PK.BAT CALL GOSALES_PK.BAT > GOSALES_PK.SQL
IF EXIST GOSALESHR_PK.BAT CALL GOSALESHR_PK.BAT > GOSALESHR_PK.SQL
IF EXIST GOSALESMR_PK.BAT CALL GOSALESMR_PK.BAT > GOSALESMR_PK.SQL
IF EXIST GOSALESRT_PK.BAT CALL GOSALESRT_PK.BAT > GOSALESRT_PK.SQL
IF EXIST GOSALESCT_PK.BAT CALL GOSALESCT_PK.BAT > GOSALESCT_PK.SQL
IF EXIST GOSALESDW_PK.BAT CALL GOSALESDW_PK.BAT > GOSALESDW_PK.SQL

:CREATE_INDEXES
REM INDEXES
IF EXIST GOSALES_INDEXES.BAT CALL GOSALES_INDEXES.BAT > GOSALES_INDEXES.SQL
IF EXIST GOSALESHR_INDEXES.BAT CALL GOSALESHR_INDEXES.BAT > GOSALESHR_INDEXES.SQL
IF EXIST GOSALESMR_INDEXES.BAT CALL GOSALESMR_INDEXES.BAT > GOSALESMR_INDEXES.SQL
IF EXIST GOSALESRT_INDEXES.BAT CALL GOSALESRT_INDEXES.BAT > GOSALESRT_INDEXES.SQL
IF EXIST GOSALESCT_INDEXES.BAT CALL GOSALESCT_INDEXES.BAT > GOSALESCT_INDEXES.SQL
IF EXIST GOSALESDW_INDEXES.BAT CALL GOSALESDW_INDEXES.BAT > GOSALESDW_INDEXES.SQL

REM CONSTRAINTS
IF EXIST GOSALES_CONSTRAINTS.BAT CALL GOSALES_CONSTRAINTS.BAT > GOSALES_CONSTRAINTS.SQL
IF EXIST GOSALESHR_CONSTRAINTS.BAT CALL GOSALESHR_CONSTRAINTS.BAT > GOSALESHR_CONSTRAINTS.SQL
IF EXIST GOSALESMR_CONSTRAINTS.BAT CALL GOSALESMR_CONSTRAINTS.BAT > GOSALESMR_CONSTRAINTS.SQL
IF EXIST GOSALESRT_CONSTRAINTS.BAT CALL GOSALESRT_CONSTRAINTS.BAT > GOSALESRT_CONSTRAINTS.SQL
IF EXIST GOSALESCT_CONSTRAINTS.BAT CALL GOSALESCT_CONSTRAINTS.BAT > GOSALESCT_CONSTRAINTS.SQL
IF EXIST GOSALESDW_CONSTRAINTS.BAT CALL GOSALESDW_CONSTRAINTS.BAT > GOSALESDW_CONSTRAINTS.SQL

REM STORED PROCEDURES
IF EXIST GOSALES_SP.BAT CALL GOSALES_SP.BAT > GOSALES_SP.SQL
IF EXIST GOSALESHR_SP.BAT CALL GOSALESHR_SP.BAT > GOSALESHR_SP.SQL
IF EXIST GOSALESMR_SP.BAT CALL GOSALESMR_SP.BAT > GOSALESMR_SP.SQL
IF EXIST GOSALESRT_SP.BAT CALL GOSALESRT_SP.BAT > GOSALESRT_SP.SQL
IF EXIST GOSALESCT_SP.BAT CALL GOSALESCT_SP.BAT > GOSALESCT_SP.SQL
IF EXIST GOSALESDW_SP.BAT CALL GOSALESDW_SP.BAT > GOSALESDW_SP.SQL

REM VIEWS
IF EXIST GOSALES_VIEWS.BAT CALL GOSALES_VIEWS.BAT > GOSALES_VIEWS.SQL
IF EXIST GOSALESHR_VIEWS.BAT CALL GOSALESHR_VIEWS.BAT > GOSALESHR_VIEWS.SQL
IF EXIST GOSALESMR_VIEWS.BAT CALL GOSALESMR_VIEWS.BAT > GOSALESMR_VIEWS.SQL
IF EXIST GOSALESRT_VIEWS.BAT CALL GOSALESRT_VIEWS.BAT > GOSALESRT_VIEWS.SQL
IF EXIST GOSALESCT_VIEWS.BAT CALL GOSALESCT_VIEWS.BAT > GOSALESCT_VIEWS.SQL
IF EXIST GOSALESDW_VIEWS.BAT CALL GOSALESDW_VIEWS.BAT > GOSALESDW_VIEWS.SQL

REM RUNSTATS
IF EXIST GOSALES_RUNSTATS.BAT CALL GOSALES_RUNSTATS.BAT > GOSALES_RUNSTATS.SQL
IF EXIST GOSALESHR_RUNSTATS.BAT CALL GOSALESHR_RUNSTATS.BAT > GOSALESHR_RUNSTATS.SQL
IF EXIST GOSALESMR_RUNSTATS.BAT CALL GOSALESMR_RUNSTATS.BAT > GOSALESMR_RUNSTATS.SQL
IF EXIST GOSALESRT_RUNSTATS.BAT CALL GOSALESRT_RUNSTATS.BAT > GOSALESRT_RUNSTATS.SQL
IF EXIST GOSALESCT_RUNSTATS.BAT CALL GOSALESCT_RUNSTATS.BAT > GOSALESCT_RUNSTATS.SQL
IF EXIST GOSALESDW_RUNSTATS.BAT CALL GOSALESDW_RUNSTATS.BAT > GOSALESDW_RUNSTATS.SQL

REM DROP TABLE script
IF EXIST GOSALES_DROP.BAT CALL GOSALES_DROP.BAT

REM VERIFY script
IF EXIST GOSALES_VERIFY.BAT CALL GOSALES_VERIFY.BAT > GOSALES_VERIFY.SQL


REM ************************************************************************
REM * Run the scripts
REM ************************************************************************

if /I "%GOSALES_ONLY_GENERATE_SQL%" == "Y" goto GOSALES_IMPORT_FINISHED

CALL GOSALES_RUN_SCRIPTS.BAT

GOTO CLEANUP

REM ************************************************************************
REM * Error messages
REM ************************************************************************

:QUITTING_MISSINGVALUE
echo.
echo MISSING VALUE - You can assign the database, schema names, tablespaces in the file "GOSALES_CONFIG.bat".
echo Quitting
echo.
GOTO CLEANUP

:QUITTING_NORESPONSE
echo.
echo No value provided - Quitting
echo.
GOTO CLEANUP

:UPDATE_ERROR
echo.
echo Error updating schemas - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:IMPORT_ERROR
echo.
echo Error importing tables - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:QUITTING
echo.
echo Script terminated by the user - Quitting
goto GOSALES_IMPORT_FINISHED

:CLEANUP
REM ************************************************************************
REM * DISPLAY THE CONTENTS OF THE ERROR LOG
REM ************************************************************************
IF NOT EXIST "%GOSALES_ERROR_LOG%" GOTO GOSALES_IMPORT_FINISHED
echo.
echo GOSALES SAMPLE DATABASE SETUP ERRORS:
echo (Please check the log files for more details)
echo ---------------------------------------------
echo.
TYPE "%GOSALES_ERROR_LOG%"

:GOSALES_IMPORT_FINISHED
REM ************************************************************************
REM * These 3 environment variables need to be cleared here since they are
REM * set in START_GOSALES_IMPORT before the db2cmd shell is launched.
REM ************************************************************************
set GOSALES_PARENT_DIR=
set GOSALES_SCRIPT_DIR=
set GOSALES_START=
